<!doctype html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">

<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    {!! SEOMeta::generate() !!}
    {!! OpenGraph::generate() !!}
    {!! JsonLd::generate() !!}
    <!-- CSRF Token -->
    <meta name="csrf-token" content="{{ csrf_token() }}">
    <!-- Scripts -->
    <script src="{{ asset('js/app.js') }}" defer></script>
    <!-- Styles -->
    @if (Session::get('theme'))
        <link href="{{ url('') . mix('css/app_' .  Session::get('theme') . '.css') }}" rel="stylesheet">
    @else
        <link href="{{ url('') . mix('css/app_light.css') }}" rel="stylesheet">
    @endif
</head>

<body>
    <div id="app">
        <nav class="navbar navbar-expand-md navbar-light bg-light shadow-sm">
            <div class="container">
                <a class="navbar-brand" href="{{ url('/') }}">
                    <img class="img-logo" src="{{ url('logo.png') }}" alt="">
                </a>
                <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarSupportedContent" aria-controls="navbarSupportedContent" aria-expanded="false" aria-label="{{ __('Toggle navigation') }}">
                    <span class="navbar-toggler-icon"></span>
                </button>

                <div class="collapse navbar-collapse" id="navbarSupportedContent">
                    <!-- Left Side Of Navbar -->
                    <ul class="navbar-nav mr-auto">
                        <li class="nav-item active">
                            <a class="nav-link" href="{{ route('homepage') }}">Home</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="{{ url('about') }}">About</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('leaderboard') }}">Leaderboard</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('meme') }}">Submit</a>
                        </li>
                    </ul>

                    <!-- Right Side Of Navbar -->
                    <ul class="navbar-nav ml-auto">
                        <span class="nav-item mx-2 my-auto" data-toggle="tooltip" data-placement="bottom" title="{{  Session::get('theme') === 'light' ? 'Dark' : 'Light' }} Theme">
                            @if (Session::get('theme') === 'dark')
                                <a class="btn btn-light" href="{{ url('/theme/light') }}" role="button"><i class="fas fa-sun text-primary"></i></a>
                            @else
                                <a class="btn btn-light" href="{{ url('/theme/dark') }}" role="button"><i class="far fa-moon text-dark"></i></a>
                            @endif
                        </span>

                        <!-- Authentication Links -->
                        @guest
                        @if (Route::has('login'))
                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('login') }}">{{ __('Login') }}</a>
                        </li>
                        @endif

                        @if (Route::has('register'))
                        <li class="nav-item">
                            <a class="nav-link" href="{{ route('register') }}">{{ __('Register') }}</a>
                        </li>
                        @endif
                        @else
                        <li class="nav-item dropdown">
                            <a id="navbarDropdown" class="nav-link dropdown-toggle" href="#" role="button" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false" v-pre>
                                {{ Auth::user()->name }}
                            </a>

                            <div class="dropdown-menu dropdown-menu-right" aria-labelledby="navbarDropdown">
                                <a class="dropdown-item" href="{{ route('dashboard') }}">
                                    {{ __('Dashboard') }}
                                </a>

                                {{-- <a class="dropdown-item" href="{{ route('logout') }}"
                                onclick="event.preventDefault();
                                document.getElementById('logout-form').submit();">
                                {{ __('Logout') }}
                                </a> --}}

                                <a class="dropdown-item" href="{{ route('logout') }}" onclick="event.preventDefault();
                                                     document.getElementById('logout-form').submit();">
                                    {{ __('Logout') }}
                                </a>

                                <form id="logout-form" action="{{ route('logout') }}" method="POST" class="d-none">
                                    @csrf
                                </form>
                            </div>
                        </li>
                        @endguest
                    </ul>
                </div>
            </div>
        </nav>
        <main class="py-4">
            @yield('content')
        </main>

        <footer class="container-fluid py-5 bg-light shadow-lg text-center">
            <div class="row">
                <div class="col-6 col-md">
                    <ul class="list-unstyled">
                        <li><a href="{{ route('homepage') }}">Home</a></li>
                    </ul>
                </div>
                <div class="col-6 col-md">
                    <ul class="list-unstyled">
                        <li><a href="{{ url('about') }}">About</a></li>
                    </ul>
                </div>
                <div class="col-6 col-md">
                    <ul class="list-unstyled">
                        <li><a href="{{ url('api') }}">API</a></li>
                    </ul>
                </div>
                <div class="col-6 col-md">
                    <ul class="list-unstyled">
                        <li><a href="{{ route('leaderboard') }}">Leaderboard</a></li>
                    </ul>
                </div>
                <div class="col-6 col-md">
                    <ul class="list-unstyled">
                        <li><a href="https://repo.getmonero.org/AnonDev/xmrmemes" target="_blank">Source Code</a></li>
                    </ul>
                </div>
                <div class="col-6 col-md">
                    <ul class="list-unstyled">
                        <li><a href="{{ route('contact') }}">Contact</a></li>
                    </ul>
                </div>
            </div>
            <div class="row">
                <div class="col-12 mt-4">
                    <a class="small text-muted" href="https://ccs.getmonero.org/" target="_blank">Proudly crowd funded by Monero's Community Crowdfunding System (CCS)</a>
                </div>
            </div>
        </footer>


    </div>
</body>

</html>
